Patient

Represents a patient who has called 999.

Usage

Patient(
    patient_id,
    category,
    outcome,
    call_timestamp,
)

Attributes

patient_id: int

Unique identifier for the patient.

category: str

Ambulance response category (“C1”, “C2”, “C3” or “C4”).

outcome: str

Call outcome (“see_and_convey” or “see_and_treat”).

call_timestamp: float

Time at which patient called 999.

wait_for_assignment: float

Time between the call and an ambulance being assigned.

response_time: float
Time between the call and ambulance arrival on scene.

Attributes

Name Description
priority Numeric priority for resource requests (lower = more urgent).

priority

Numeric priority for resource requests (lower = more urgent).

priority

Methods

Name Description
__init__() Create instance of Patient.

__init__()

Create instance of Patient.

Usage

__init__(patient_id, category, outcome, call_timestamp)
Parameters
patient_id: int

Unique identifier for the patient.

category: str

Ambulance response category (“C1”, “C2”, “C3” or “C4”).

outcome: str

Call outcome (“see_and_convey” or “see_and_treat”).

call_timestamp: float
Time at which patient called 999.