SimConfig

Configuration for a simulation run.

Usage

SimConfig(
    arrivals_json,
    times_json,
    param_csv,
)

Stores input data and run settings used by the model.

Attributes

dist_config: dict

Dictionary with all distribution settings, in required format for sim-tools DistributionRegistry.

n_ambulances: int

Size of ambulance resource pool.

warm_up_period: int

Duration of the warm-up period in minutes.

data_collection_period: int

Duration of the data collection period in minutes.

n_reps: int

Number of replications to run.

cores: int
Number of CPU cores to use for parallel execution. To use all available cores, set to -1. For sequential execution, set to 1.

Methods

Name Description
__init__() Initialise simulation configuration.

__init__()

Initialise simulation configuration.

Usage

__init__(arrivals_json, times_json, param_csv)
Parameters
arrivals_json: str | Path

Path to JSON file containing arrival distribution configuration.

times_json: str | Path

Path to JSON file containing time distribution configuration.

param_csv: str | Path
Path to CSV containing model parameters.