plot_warm_up()

Plot warm-up trajectories for one metric and response category.

Usage

plot_warm_up(
    audit,
    metric,
    category=None,
)

Shows one line per run for the cumulative mean trajectories, and overlays the overall cumulative mean across runs.

Parameters

audit: pd.DataFrame

Warm-up audit results.

metric

Name of the performance measure to visualise.

category: str = None
Response category to plot.

Returns

fig: matplotlib.figure.Figure

A Matplotlib Figure containing cumulative mean trajectories for each run and the overall cumulative mean.

ax: matplotlib.axes.Axes
The Matplotlib Axes object.