WarmUpAuditor
Warm-up auditor - records cumulative mean results at intervals.
Usage
WarmUpAuditor(
model,
interval,
)Attributes
model: Model-
A model instance that has not yet been run (model.run()).
interval: int-
Audit frequency in minutes.
audit_results: list-
List of dictionaries containing audit snapshots at each interval.
response_categories: list- List of response categories.
Methods
| Name | Description |
|---|---|
| __init__() | Initialise WarmUpAuditor. |
| run() | Run auditor alongside simulation model. |
| to_df() | Convert audit results to dataframe. |
__init__()
Initialise WarmUpAuditor.
Usage
__init__(model, interval)Parameters
model: Model-
A model instance that has not yet been run (model.run()).
interval: int- Audit frequency in minutes.
run()
Run auditor alongside simulation model.
Usage
run()to_df()
Convert audit results to dataframe.
Usage
to_df()Returns
df: pd.DataFrame- Audit results with one row per run, time, and category.