build_arrival_config()
Determine arrival parameters and create config dict.
Usage
build_arrival_config(arrivals)Parameters
arrivals: pd.DataFrame- Count of arrivals by weekday, response category and outcome.
Returns
dict- Dictionary containing the configuration dictionary, as well as other tables and outputs from processing, that can be used to help check assumptions in the arrival modelling.