fit_config()
Fit distributions for each metric and category from raw time data.
Usage
fit_config(
time_data,
time_data_unit,
metric_config,
)If specified in metric_config, times may be additional split depending on whether patients were conveyed (see & convey) or not (see & treat).
Parameters
time_data: pd.DataFrame-
Raw time data.
time_data_unit: str-
Whether the provided raw data is in seconds (“s”) or minutes (“m”).
metric_config: dict- Dictionary where keys are the times, then sub dict, has dist sim-tools name and column mapping to column in raw time data for that time.
Returns
config: dict- Dictionary in format suitable for sim-tools distribution registry with generated parameters for dists by category etc.